@@ -13,7 +13,8 @@ char special[1][1] = { };
 char operator[OPERATOR_NUMBER][5] = {
     { ":-" }, { "-->" }, { "," }, { ";" }, { "?-" }, { "." },
     { "+" }, { "-" }, { "*" }, { "/" }, { "//" }, { "<<" }, { ">>" },
-    { "\\" }, { "/\\" }, { "\\/" }, { "mod" }, { "^" }, { "**" }, { "xor" },
+    { "\\" }, { "/\\" }, { "\\/" }, { "mod" }, { "^" }, { "**" },
+	{ "xor" },
 };
 
 char function[FUNCTION_NUMBER][12] = {
@@ -75,7 +76,7 @@ char builtin[BUILTIN_NUMBER][30] = {
     { "copy_term" }, { "set_prolog_flag" },
     { "current_input" }, { "current_output" }, { "at_end_of_stream" },
     { "peek_code" }, { "peek_char" }, { "peek_byte" },
-    { "stream_property" }, { "dynamic" },
+    { "stream_property" }, { "dynamic" }, { "subsumes_term" },
     { "create_client_socket" }, { "create_server_socket" },
     { "recv_socket" }, { "close_socket" }, { "initialization" },
     { "string_atom" },
@@ -109,7 +110,7 @@ char extended[EXTENDED_NUMBER][30] = {
     { "gpio_event_read" },
     { "gpio_close" }, { "sleep" }, { "usleep" },
     { "format" }, { "gr_open" }, { "gr_close" }, { "gr_pset" },
-	{ "gr_circle" },
+    { "gr_circle" },
     { "gr_rect" }, { "gr_line" },
 };
 
